California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| CAMPAIGN FINANCE: Candidates & Elected Officials
Choose a Listing: Certified Election Candidates Incumbent Elected State Officials Candidates and Elected Officials By Name Who filed a Statement of Intention to run for What State Office? (Filers may not have qualified for the ballot) CalPERS and CalSTRS Candidate Filings, Scanned Images |
Go to Section:
| Statewide Candidates
| State Senate Candidates
| State Assembly Candidates
Choose an Election: 2022 PRIMARY 2021 SPECIAL ELECTION (ASSEMBLY 54) Prior Elections 2021 SPECIAL ELECTION (ASSEMBLY 79) 2021 SPECIAL ELECTION (STATE SENATE 30) 2020 GENERAL 2020 SPECIAL RUNOFF (STATE SENATE 28) 2020 PRIMARY 2020 SPECIAL ELECTION (STATE SENATE 28) 2019 SPECIAL RUNOFF (ASSEMBLY 01) 2019 SPECIAL ELECTION (ASSEMBLY 01) 2019 SPECIAL RUNOFF (STATE SENATE 01) 2019 SPECIAL RUNOFF (STATE SENATE 33) 2019 SPECIAL ELECTION (STATE SENATE 01) 2019 SPECIAL ELECTION (STATE SENATE 33) 2018 GENERAL 2018 SPECIAL RUNOFF (STATE SENATE 32) 2018 PRIMARY 2018 SPECIAL ELECTION (STATE SENATE 32) 2018 SPECIAL ELECTION (STATE SENATE 29) 2018 SPECIAL RUNOFF (ASSEMBLY 45) 2018 SPECIAL RUNOFF (ASSEMBLY 39) 2018 SPECIAL ELECTION (ASSEMBLY 45) 2018 SPECIAL ELECTION (ASSEMBLY 54) 2018 SPECIAL ELECTION (ASSEMBLY 39) 2017 SPECIAL RUNOFF (ASSEMBLY 51) 2017 SPECIAL ELECTION (ASSEMBLY 51) 2016 GENERAL 2016 PRIMARY 2016 SPECIAL ELECTION (ASSEMBLY 31) 2015 SPECIAL RUNOFF (STATE SENATE 07) 2015 SPECIAL ELECTION (STATE SENATE 37) 2015 SPECIAL ELECTION (STATE SENATE 21) 2015 SPECIAL ELECTION (STATE SENATE 07) 2014 SPECIAL ELECTION (STATE SENATE 35) 2014 GENERAL 2014 PRIMARY 2014 SPECIAL ELECTION (STATE SENATE 23) 2013 SPECIAL ELECTION (ASSEMBLY 54) 2013 SPECIAL RUNOFF (ASSEMBLY 45) 2013 SPECIAL RUNOFF (ASSEMBLY 52) 2013 SPECIAL ELECTION (STATE SENATE 26) 2013 SPECIAL ELECTION (ASSEMBLY 45) 2013 SPECIAL ELECTION (ASSEMBLY 52) 2013 SPECIAL RUNOFF (STATE SENATE 16) 2013 SPECIAL ELECTION (ASSEMBLY 80) 2013 SPECIAL ELECTION (STATE SENATE 16) 2013 SPECIAL RUNOFF (STATE SENATE 32) 2013 SPECIAL ELECTION (STATE SENATE 40) 2013 SPECIAL ELECTION (STATE SENATE 32) 2013 SPECIAL ELECTION (STATE SENATE 04) 2012 GENERAL 2012 SPECIAL ELECTION (STATE SENATE 04) 2012 PRIMARY 2011 SPECIAL RUNOFF (ASSEMBLY 04) 2011 SPECIAL ELECTION (ASSEMBLY 04) 2011 SPECIAL ELECTION (STATE SENATE 17) 2011 SPECIAL ELECTION (STATE SENATE 28) 2011 SPECIAL RUNOFF (STATE SENATE 01) 2010 GENERAL 2010 SPECIAL ELECTION (STATE SENATE 01) 2010 SPECIAL RUNOFF (STATE SENATE 15) 2010 SPECIAL ELECTION (STATE SENATE 15) 2010 PRIMARY 2010 SPECIAL RUNOFF (STATE SENATE 37) 2010 SPECIAL RUNOFF (ASSEMBLY 43) 2010 SPECIAL ELECTION (STATE SENATE 37) 2010 SPECIAL ELECTION (ASSEMBLY 43) 2010 SPECIAL RUNOFF (ASSEMBLY 72) 2009 SPECIAL ELECTION (ASSEMBLY 72) 2009 SPECIAL ELECTION (ASSEMBLY 51) 2009 SPECIAL RUNOFF (STATE SENATE 26) 2009 SPECIAL ELECTION (STATE SENATE 26) 2008 GENERAL 2008 PRIMARY 2008 RECALL (STATE SENATE 12) 2008 SPECIAL RUNOFF (ASSEMBLY 55) 2007 SPECIAL ELECTION (ASSEMBLY 55) 2007 SPECIAL ELECTION (ASSEMBLY 39) 2006 GENERAL 2006 PRIMARY 2006 SPECIAL RUNOFF (STATE SENATE 35) 2006 SPECIAL ELECTION (STATE SENATE 35) 2005 SPECIAL ELECTION (ASSEMBLY 53) 2004 GENERAL 2004 PRIMARY 2003 SPECIAL ELECTION (GOVERNOR) 2002 GENERAL 2002 PRIMARY 2001 SPECIAL ELECTION (ASSEMBLY 49) 2001 SPECIAL RUNOFF (ASSEMBLY 65) 2001 SPECIAL ELECTION (STATE SENATE 24) 2001 SPECIAL ELECTION (ASSEMBLY 65) 2000 GENERAL 2000 PRIMARY
Also check Late Contribution filings. These reports are independent of the comprehensive disclosure reports that are linked here until semi-annual filings are submitted.
SENATE DISTRICTS
STATE SENATE 01
GAINES, EDWARD T ROWEN, ROBERT J.
| STATE SENATE 03
DODD, BILL YAMADA, MARIKO M.
STATE SENATE 05
GALGIANI, CATHLEEN NAKANISHI, ALAN S.
| STATE SENATE 07
GLAZER, STEVEN RUBAY, JOSEPH A.
STATE SENATE 09
SKINNER, NANCY SWANSON, SANDRE
| STATE SENATE 11
KIM, JANE WIENER, SCOTT D.
STATE SENATE 13
CIARDELLA, RICHARD HILL, JERRY A.
| STATE SENATE 15
BEALL, JIM CAMPOS, NORA ELIA
STATE SENATE 17
KAIN, PALMER MONNING, WILLIAM W.
| STATE SENATE 19
JACKSON, HANNAH-BETH WALCH, COLIN
STATE SENATE 21
ERVIN, JOHNATHON WILK, SCOTT T.
| STATE SENATE 23
MORRELL, MIKE O'DONNELL, RONALD J.
STATE SENATE 25
ANTONOVICH, MICHAEL D. PORTANTINO, ANTHONY
| STATE SENATE 27
FAZIO, STEVE STERN, HENRY
STATE SENATE 29
CHANG, LING LING NEWMAN, JOSH B.
| STATE SENATE 31
REED, RICHARD ROTH, RICHARD D.
STATE SENATE 33
LARA, RICARDO ROBSON, HONOR MIMI
| STATE SENATE 35
BRADFORD, STEVEN FURUTANI, WARREN
STATE SENATE 37
GRAYSON, ARI E. MOORLACH, JOHN M.W.
| STATE SENATE 39
ATKINS, TONI G. RENISON, JOHN
ASSEMBLY DISTRICTS
ASSEMBLY 01
COENEN, DONN DAHLE, BRIAN
| ASSEMBLY 02
ANTON, KENNETH R. WOOD, JIM
ASSEMBLY 03
GALLAGHER, JAMES RITCHIE, EDWARD H
| ASSEMBLY 04
AGUIAR-CURRY, CECILIA SCHAUPP, CHARLES E.
ASSEMBLY 05
BIGELOW, FRANK CARABAS, ROBERT J
| ASSEMBLY 06
CAPLES, BRIAN KILEY, KEVIN
ASSEMBLY 07
BROWN, RYAN K. MC CARTY, KEVIN
| ASSEMBLY 08
BLOISE, NICK E. COOLEY, KEN
ASSEMBLY 09
COOPER, JIM GORSULOWSKY, TIMOTHY S.
| ASSEMBLY 10
JACOBI, VERONICA S. LEVINE, MARC
ASSEMBLY 11
FRAZIER, JR., JAMES L MILLER, DAVID J.
| ASSEMBLY 12
FLORA, HEATH VOGEL, KEN
ASSEMBLY 13
EGGMAN, SUSAN LINCOLN, KEVIN
| ASSEMBLY 14
GRAYSON, TIM TORLAKSON, MAE
ASSEMBLY 15
CHIARA, CLAIRE THURMOND, TONY
| ASSEMBLY 16
BAKER, CATHARINE COOK-KALLIO, CHERYL
ASSEMBLY 17
CHIU, DAVID DEL CARLO, MATTHEW S.
| ASSEMBLY 18
BONTA, ROB SLONSKY-BREAULT, ROSEANN
ASSEMBLY 19
TAYLOR, CARLOS TING, PHIL
| ASSEMBLY 20
QUIRK, BILL WONG, LUIS A.
ASSEMBLY 21
GRAY, ADAM C. OPINSKI, GREGORY J.
| ASSEMBLY 22
KIESEL, ART MULLIN, KEVIN C.
ASSEMBLY 23
MORRIS, GWEN L PATTERSON, JIM
| ASSEMBLY 24
BERMAN, MARC VEENKER, VICKI
ASSEMBLY 25
BRUNTON, ROBERT L. CHU, KANSEN
| ASSEMBLY 26
MACARENO, RUBEN MATHIS, DEVON J.
ASSEMBLY 27
KALRA, ASH NGUYEN, MADISON
| ASSEMBLY 28
LOW, EVAN SCLAVOS, NICHOLAS C
ASSEMBLY 29
ROBERTS, SIERRA STONE, MARK
| ASSEMBLY 30
CABALLERO, ANNA CERVANTEZ ALEJO, KARINA
ASSEMBLY 31
ARAMBULA, JOAQUIN OLIVIER, CLINT
| ASSEMBLY 32
RAMIREZ, MANUEL A. SALAS JR., RUDY
ASSEMBLY 33
MARKOVICH, PETER SCOTT OBERNOLTE, JAY
| ASSEMBLY 34
FONG, VINCENT SWANLUND, PERRIN A
ASSEMBLY 35
CUNNINGHAM, JORDAN LEGG, DAWN ORTIZ
| ASSEMBLY 36
FOX, STEVE LACKEY, THOMAS W.
ASSEMBLY 37
FULLER, EDWARD L. LIMON, S. MONIQUE
| ASSEMBLY 38
ACOSTA, DANTE SMITH, CHRISTY
ASSEMBLY 39
BOCANEGRA, RAUL LOPEZ, PATTY
| ASSEMBLY 40
MEDINA, ABIGAIL M. STEINORTH, MARC
ASSEMBLY 41
HIGGINS, CASEY C. HOLDEN, CHRIS
| ASSEMBLY 42
MAYES, CHAD RODRIGUEZ, GREG
ASSEMBLY 43
FRIEDMAN, LAURA KASSAKHIAN, ARDY
| ASSEMBLY 44
IRWIN, JACQUI V. NELSON, KERRY J.
ASSEMBLY 45
DABABNEH, MATTHEW KOWAL, JERRY S.
| ASSEMBLY 46
NAZARIAN, ADRIN RUPERT, ANGELA
ASSEMBLY 47
BROWN, CHERYL REYES, ELOISE GOMEZ
| ASSEMBLY 48
ELLENSON, CORY H RUBIO, BLANCA
ASSEMBLY 49
AMUNDSON, PETER CHAU, ED
| ASSEMBLY 50
BLOOM, RICHARD CRAFFEY, MATTHEW G.
ASSEMBLY 51
EVERLING, MIKE GOMEZ, JIMMY
| ASSEMBLY 52
AVILA, PAUL VINCENT RODRIGUEZ, FREDDIE
ASSEMBLY 53
MENDOZA, SANDRA Y. SANTIAGO, MIGUEL
| ASSEMBLY 54
RATCLIFF, GLEN RIDLEY-THOMAS, SEBASTIAN M.
ASSEMBLY 55
CHEN, PHILLIP FRITCHLE, GREGG D.
| ASSEMBLY 56
GARCIA, EDUARDO
ASSEMBLY 57
CALDERON, IAN TOPALIAN, RITA H.
| ASSEMBLY 58
ALVARADO, RAMIRO GARCIA, CRISTINA
ASSEMBLY 59
JONES-SAWYER SR., REGINALD BYRON
| ASSEMBLY 60
CERVANTES, SABRINA LINDER, ERIC
ASSEMBLY 61
DIAZ, HECTOR MEDINA, JOSE J.
| ASSEMBLY 62
BRUNO, BARON BURKE, AUTUMN LEAL, MARCO ANTONIO "TONY"
ASSEMBLY 63
MILLER, ADAM J. RENDON, ANTHONY
| ASSEMBLY 64
GIPSON, MIKE SANFORD, THERESA
ASSEMBLY 65
KIM, YOUNG O. QUIRK-SILVA, SHARON
| ASSEMBLY 66
HADLEY, DAVID F. MURATSUCHI, AL
ASSEMBLY 67
LOPEZ (WITHDRAWN), JORGE R. MELENDEZ, MELISSA
| ASSEMBLY 68
CHOI, STEVEN PANAHI, SEAN JAY
ASSEMBLY 69
DALY, TOM VELARDE-GARCIA, OFELIA
| ASSEMBLY 70
FLORES-GIBSON, MARTHA O'DONNELL, PATRICK
ASSEMBLY 71
HAMEL, LEO VOEPEL, RANDY G.
| ASSEMBLY 72
ALBERT-SHERIDAN, LENORE L. ALLEN, TRAVIS
ASSEMBLY 73
BROUGH, WILLIAM (BILL) ISLAM, MESBAH
| ASSEMBLY 74
HARPER, MATTHEW ONOFRE, KARINA
ASSEMBLY 75
MASIEL, ANDREW WALDRON, MARIE
| ASSEMBLY 76
CHAVEZ, ROCKY KROUSE, THOMAS
ASSEMBLY 77
MAIENSCHEIN, BRIAN VASQUEZ, MELINDA K
| ASSEMBLY 78
GLORIA, TODD MELTON, KEVIN D
ASSEMBLY 79
MOORE, JOHN S. WEBER, SHIRLEY
| ASSEMBLY 80
GONZALEZ, LORENA S. PICKARD, LINCOLN M.